@@ -7,11 +7,17 @@ Utility script
 
 import sys
 import datetime
+import re
 from db_sync_tool.utility import mode, system, helper, output
 
 database_dump_file_name = None
 
 
+class DatabaseSystem:
+    MYSQL = 'MySQL'
+    MARIADB = 'MariaDB'
+
+
 def run_database_command(client, command):
     """
     Run a database command using the "mysql -e" command
@@ -81,7 +87,7 @@ def get_database_tables_like(client, name):
     :return: Dictionary
     """
     _dbname = system.config[client]['db']['name']
-    _tables = run_database_command(client, f'SHOW TABLES FROM dmm-master LIKE \'%{name}%\';').strip()
+    _tables = run_database_command(client, f'SHOW TABLES FROM {_dbname} LIKE \'%{name}%\';').strip()
     if _tables != '':
         return _tables.split('\n')[1:]
     return
@@ -157,3 +163,30 @@ def count_tables(client, filepath):
             output.host_to_subject(client),
             f'{int(_count)} table(s) exported'
         )
+
+
+def get_database_version(client):
+    """
+    Check the database version and distinguish between mysql and mariadb
+    :param client:
+    :return: Tuple<String,String>
+    """
+    _database_system = None
+    _version_number = None
+    try:
+        _database_version = run_database_command(mode.Client.ORIGIN, 'SELECT VERSION();').splitlines()[1]
+        _database_system = DatabaseSystem.MYSQL
+
+        _version_number = re.search('(\d+\.)?(\d+\.)?(\*|\d+)', _database_version).group()
+
+        if DatabaseSystem.MARIADB.lower() in _database_version.lower():
+            _database_system = DatabaseSystem.MARIADB
+
+        output.message(
+            output.host_to_subject(client),
+            f'Database version: {_database_system} v{_version_number}',
+            True
+        )
+    finally:
+        return _database_system, _version_number
+
