@@ -1,9 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: future_fstrings -*-
 
+"""
+Parser script
+"""
+
 import sys
 from db_sync_tool.utility import mode, system, output, helper
-from db_sync_tool.remote import client as remote_client, utility as remote_utility
+from db_sync_tool.remote import client as remote_client
 
 
 class Framework:
@@ -11,9 +15,30 @@ class Framework:
     SYMFONY = 'Symfony'
     DRUPAL = 'Drupal'
     WORDPRESS = 'Wordpress'
+    LARAVEL = 'Laravel'
     MANUAL = 'Manual'
 
 
+mapping = {
+    Framework.TYPO3: [
+        'LocalConfiguration.php'
+    ],
+    Framework.SYMFONY: [
+        '.env',
+        'parameters.yml'
+    ],
+    Framework.DRUPAL: [
+        'settings.php'
+    ],
+    Framework.WORDPRESS: [
+        'wp-config.php'
+    ],
+    Framework.LARAVEL: [
+        '.env'
+    ]
+}
+
+
 def get_database_configuration(client):
     """
     Getting database configuration of given client and defined sync base (framework type)
@@ -25,7 +50,12 @@ def get_database_configuration(client):
     # check framework type
     _base = ''
 
-    if 'type' in system.config and ('path' in system.config[mode.Client.ORIGIN] or 'path' in system.config[mode.Client.TARGET]):
+    automatic_type_detection()
+
+    if 'type' in system.config and (
+            'path' in system.config[mode.Client.ORIGIN] or
+            'path' in system.config[mode.Client.TARGET]
+    ):
         _type = system.config['type'].lower()
         if _type == 'typo3':
             # TYPO3 sync base
@@ -34,11 +64,14 @@ def get_database_configuration(client):
             # Symfony sync base
             _base = Framework.SYMFONY
         elif _type == 'drupal':
-            # Symfony sync base
+            # Drupal sync base
             _base = Framework.DRUPAL
         elif _type == 'wordpress':
-            # Symfony sync base
+            # Wordpress sync base
             _base = Framework.WORDPRESS
+        elif _type == 'laravel':
+            # Laravel sync base
+            _base = Framework.LARAVEL
         else:
             sys.exit(
                 output.message(
@@ -50,8 +83,13 @@ def get_database_configuration(client):
     elif 'db' in system.config['origin'] or 'db' in system.config['target']:
         _base = Framework.MANUAL
     else:
-        # Default is TYPO3 sync base
-        _base = Framework.TYPO3
+        sys.exit(
+            output.message(
+                output.Subject.ERROR,
+                f'Missing framework type or database credentials',
+                False
+            )
+        )
 
     sys.path.append('../recipes')
     if _base == Framework.TYPO3:
@@ -74,6 +112,11 @@ def get_database_configuration(client):
         from ..recipes import wordpress
         _parser = wordpress
 
+    elif _base == Framework.LARAVEL:
+        # Import Symfony parser
+        from ..recipes import laravel
+        _parser = laravel
+
     if client == mode.Client.ORIGIN:
         output.message(
             output.Subject.INFO,
@@ -165,3 +208,31 @@ def validate_database_credentials(client):
                 f'Database credential "{_key}" valid',
                 verbose_only=True
             )
+
+
+def automatic_type_detection():
+    """
+    Detects the framework type by the provided path using the default mapping
+    """
+    if 'type' in system.config or 'db' in system.config['origin'] or 'db' in system.config[
+        'target']:
+        return
+
+    type = None
+    file = None
+
+    for _client in [mode.Client.ORIGIN, mode.Client.TARGET]:
+        if 'path' in system.config[_client]:
+            file = helper.get_file_from_path(system.config[_client]['path'])
+            for _key, _files in mapping.items():
+                if file in _files:
+                    type = _key
+
+    if type:
+        output.message(
+            output.Subject.LOCAL,
+            f'Automatic framework type detection '
+            f'{output.CliFormat.BLACK}{file}{output.CliFormat.ENDC}',
+            verbose_only=True
+        )
+        system.config['type'] = type
